# Generated by ariadne-codegen on 2024-03-05 05:57
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import ReportUsageFragment


class ReportUsage(BaseModel):
    report_usage: "ReportUsageReportUsage" = Field(alias="reportUsage")


class ReportUsageReportUsage(ReportUsageFragment):
    pass


ReportUsage.update_forward_refs()
ReportUsageReportUsage.update_forward_refs()



# Generated by ariadne-codegen on 2024-03-05 05:57
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import ReportUsageFragment


class ReportUsageBulk(BaseModel):
    report_usage_bulk: List["ReportUsageBulkReportUsageBulk"] = Field(
        alias="reportUsageBulk"
    )


class ReportUsageBulkReportUsageBulk(ReportUsageFragment):
    pass


ReportUsageBulk.update_forward_refs()
ReportUsageBulkReportUsageBulk.update_forward_refs()
